@@ -7,26 +7,26 @@ from mnapy import Wire
 
 class Relay:
     def __init__(
-            self,
-            context,
-            Transient_Resistance,
-            Transient_Voltage,
-            Open_Resistance,
-            units,
-            Transient_Current,
-            options_units,
-            option_limits,
-            Inductance,
-            Coil_Resistance,
-            Closed_Resistance,
-            Must_Operate_Voltage,
-            Must_Release_Voltage,
-            Input_Voltage1,
-            options,
-            Initial_Current,
-            Status,
-            tag,
-            Equivalent_Current,
+        self,
+        context,
+        Transient_Resistance,
+        Transient_Voltage,
+        Open_Resistance,
+        units,
+        Transient_Current,
+        options_units,
+        option_limits,
+        Inductance,
+        Coil_Resistance,
+        Closed_Resistance,
+        Must_Operate_Voltage,
+        Must_Release_Voltage,
+        Input_Voltage1,
+        options,
+        Initial_Current,
+        Status,
+        tag,
+        Equivalent_Current,
     ):
         self.Transient_Resistance = Transient_Resistance
         self.Transient_Voltage = Transient_Voltage
@@ -60,13 +60,13 @@ class Relay:
     def Set_Inductance(self, setter: float) -> None:
         None
         if (
-                abs(setter) >= abs(self.option_limits.Inductance[0])
-                and abs(setter) <= abs(self.option_limits.Inductance[1])
+            abs(setter) >= abs(self.option_limits.Inductance[0])
+            and abs(setter) <= abs(self.option_limits.Inductance[1])
         ) or abs(setter) == 0:
             self.Inductance = setter
             self.conserve_energy()
         else:
-            print(self.Designator + " -> Value is outside of limits.")
+            print(self.Designator + ":=" + setter + " -> Value is outside of limits.")
 
     def Get_Inductance(self) -> float:
         None
@@ -75,12 +75,12 @@ class Relay:
     def Set_Coil_Resistance(self, setter: float) -> None:
         None
         if (
-                abs(setter) >= abs(self.option_limits.Coil_Resistance[0])
-                and abs(setter) <= abs(self.option_limits.Coil_Resistance[1])
+            abs(setter) >= abs(self.option_limits.Coil_Resistance[0])
+            and abs(setter) <= abs(self.option_limits.Coil_Resistance[1])
         ) or abs(setter) == 0:
             self.Coil_Resistance = setter
         else:
-            print(self.Designator + " -> Value is outside of limits.")
+            print(self.Designator + ":=" + setter + " -> Value is outside of limits.")
 
     def Get_Coil_Resistance(self) -> float:
         None
@@ -89,22 +89,22 @@ class Relay:
     def Set_Must_Operate_Voltage(self, setter: float) -> None:
         None
         if (
-                abs(setter) >= abs(self.option_limits.Must_Operate_Voltage[0])
-                and abs(setter) <= abs(self.option_limits.Must_Operate_Voltage[1])
+            abs(setter) >= abs(self.option_limits.Must_Operate_Voltage[0])
+            and abs(setter) <= abs(self.option_limits.Must_Operate_Voltage[1])
         ) or abs(setter) == 0:
             self.Must_Operate_Voltage = setter
         else:
-            print(self.Designator + " -> Value is outside of limits.")
+            print(self.Designator + ":=" + setter + " -> Value is outside of limits.")
 
     def Set_Must_Release_Voltage(self, setter: float) -> None:
         None
         if (
-                abs(setter) >= abs(self.option_limits.Must_Release_Voltage[0])
-                and abs(setter) <= abs(self.option_limits.Must_Release_Voltage[1])
+            abs(setter) >= abs(self.option_limits.Must_Release_Voltage[0])
+            and abs(setter) <= abs(self.option_limits.Must_Release_Voltage[1])
         ) or abs(setter) == 0:
             self.Must_Release_Voltage = setter
         else:
-            print(self.Designator + " -> Value is outside of limits.")
+            print(self.Designator + ":=" + setter + " -> Value is outside of limits.")
 
     def Get_Must_Release_Voltage(self) -> float:
         None
@@ -113,27 +113,42 @@ class Relay:
     def Set_Closed_Resistance(self, setter: float) -> None:
         None
         if (
-                abs(setter) >= abs(self.option_limits.Closed_Resistance[0])
-                and abs(setter) <= abs(self.option_limits.Closed_Resistance[1])
+            abs(setter) >= abs(self.option_limits.Closed_Resistance[0])
+            and abs(setter) <= abs(self.option_limits.Closed_Resistance[1])
         ) or abs(setter) == 0:
             self.Closed_Resistance = setter
         else:
-            print(self.Designator + " -> Value is outside of limits.")
+            print(self.Designator + ":=" + setter + " -> Value is outside of limits.")
 
     def Get_Closed_Resistance(self) -> float:
         None
         return self.Closed_Resistance
 
+    def Set_Open_Resistance(self, setter: float) -> None:
+        None
+        if (
+            abs(setter) >= abs(self.option_limits.Open_Resistance[0])
+            and abs(setter) <= abs(self.option_limits.Open_Resistance[1])
+        ) or abs(setter) == 0:
+            self.Open_Resistance = setter
+        else:
+            print(self.Designator + ":=" + setter + " -> Value is outside of limits.")
+
+    def Get_Open_Resistance(self) -> float:
+        None
+        return self.Open_Resistance
+    
     def reset(self) -> None:
         None
-        if (self.context.integration_method == "trapezoidal"):
+        if self.context.integration_method == "trapezoidal":
             self.Transient_Resistance = (2 * self.Inductance) / self.context.time_step
             self.Transient_Voltage = 0
             self.Transient_Current = self.Initial_Current
             self.Equivalent_Current = (
-                    self.Transient_Voltage / self.Transient_Resistance + self.Transient_Current
+                self.Transient_Voltage / self.Transient_Resistance
+                + self.Transient_Current
             )
-        elif (self.context.integration_method == "backward_euler"):
+        elif self.context.integration_method == "backward_euler":
             self.Transient_Resistance = self.Inductance / self.context.time_step
             self.Transient_Voltage = 0
             self.Transient_Current = self.Initial_Current
@@ -143,16 +158,17 @@ class Relay:
             self.Transient_Voltage = 0
             self.Transient_Current = self.Initial_Current
             self.Equivalent_Current = (
-                    self.Transient_Voltage / self.Transient_Resistance + self.Transient_Current
+                self.Transient_Voltage / self.Transient_Resistance
+                + self.Transient_Current
             )
 
     def update(self) -> None:
         None
         if self.Input_Voltage1 >= self.Must_Operate_Voltage:
             if (
-                    self.context.Params.SystemFlags.FlagSimulating
-                    and self.context.solutions_ready
-                    and self.context.simulation_time > self.context.time_step
+                self.context.Params.SystemFlags.FlagSimulating
+                and self.context.solutions_ready
+                and self.context.simulation_time > self.context.time_step
             ):
                 self.Status = self.context.Params.SystemConstants.ON
             else:
@@ -175,8 +191,9 @@ class Relay:
                 self.Nodes[2], self.Nodes[3], self.Closed_Resistance
             )
         else:
-            self.context.stamp_node(self.Nodes[2], self.Open_Resistance)
-            self.context.stamp_node(self.Nodes[3], self.Open_Resistance)
+            self.context.stamp_resistor(
+                self.Nodes[2], self.Nodes[3], self.Open_Resistance
+            )
 
     def SetId(self, Id: str) -> None:
         None
@@ -221,48 +238,63 @@ class Relay:
             voltage: float = self.context.get_voltage(self.Nodes[0], self.Nodes[1])
             self.Input_Voltage1 = voltage
 
-            self.Transient_Voltage = voltage - (self.Coil_Resistance * (self.Equivalent_Current / (1 + self.Coil_Resistance / self.Transient_Resistance)) + 
-                (voltage / (self.Transient_Resistance + self.Coil_Resistance)))
-            
-            if (self.context.integration_method == "trapezoidal"):
-                self.Transient_Resistance = (2 * self.Inductance) / self.context.time_step
+            self.Transient_Voltage = voltage - (
+                self.Coil_Resistance
+                * (
+                    self.Equivalent_Current
+                    / (1 + self.Coil_Resistance / self.Transient_Resistance)
+                )
+                + (voltage / (self.Transient_Resistance + self.Coil_Resistance))
+            )
+
+            if self.context.integration_method == "trapezoidal":
+                self.Transient_Resistance = (
+                    2 * self.Inductance
+                ) / self.context.time_step
                 self.Transient_Current = (
-                    self.Transient_Voltage / self.Transient_Resistance + self.Equivalent_Current
+                    self.Transient_Voltage / self.Transient_Resistance
+                    + self.Equivalent_Current
                 )
                 self.Equivalent_Current = (
-                        self.Transient_Voltage / self.Transient_Resistance
-                        + self.Transient_Current
+                    self.Transient_Voltage / self.Transient_Resistance
+                    + self.Transient_Current
                 )
-            elif (self.context.integration_method == "backward_euler"):
+            elif self.context.integration_method == "backward_euler":
                 self.Transient_Resistance = self.Inductance / self.context.time_step
                 self.Transient_Current = (
-                    self.Transient_Voltage / self.Transient_Resistance + self.Transient_Current
+                    self.Transient_Voltage / self.Transient_Resistance
+                    + self.Transient_Current
                 )
                 self.Equivalent_Current = self.Transient_Current
             else:
-                self.Transient_Resistance = (2 * self.Inductance) / self.context.time_step
+                self.Transient_Resistance = (
+                    2 * self.Inductance
+                ) / self.context.time_step
                 self.Transient_Current = (
-                    self.Transient_Voltage / self.Transient_Resistance + self.Equivalent_Current
+                    self.Transient_Voltage / self.Transient_Resistance
+                    + self.Equivalent_Current
                 )
                 self.Equivalent_Current = (
-                        self.Transient_Voltage / self.Transient_Resistance
-                        + self.Transient_Current
+                    self.Transient_Voltage / self.Transient_Resistance
+                    + self.Transient_Current
                 )
 
     def conserve_energy(self) -> None:
         None
-        if (self.context.integration_method == "trapezoidal"):
+        if self.context.integration_method == "trapezoidal":
             self.Transient_Resistance = (2 * self.Inductance) / self.context.time_step
             self.Equivalent_Current = (
-                    self.Transient_Voltage / self.Transient_Resistance + self.Transient_Current
+                self.Transient_Voltage / self.Transient_Resistance
+                + self.Transient_Current
             )
-        elif (self.context.integration_method == "backward_euler"):
+        elif self.context.integration_method == "backward_euler":
             self.Transient_Resistance = self.Inductance / self.context.time_step
-            self.Equivalent_Current = (self.Transient_Voltage / self.Transient_Resistance)
+            self.Equivalent_Current = self.Transient_Voltage / self.Transient_Resistance
         else:
             self.Transient_Resistance = (2 * self.Inductance) / self.context.time_step
             self.Equivalent_Current = (
-                    self.Transient_Voltage / self.Transient_Resistance + self.Transient_Current
+                self.Transient_Voltage / self.Transient_Resistance
+                + self.Transient_Current
             )
 
     def GetElementType(self) -> int:
