@@ -1,4 +1,5 @@
 class VoltageControlledSwitchLimits:
-    def __init__(self, Closed_Resistance, High_Voltage):
+    def __init__(self, Closed_Resistance, High_Voltage, Open_Resistance):
         self.Closed_Resistance = Closed_Resistance
         self.High_Voltage = High_Voltage
+        self.Open_Resistance = Open_Resistance
